==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/confidentialledger/kotlin/inputs/CertificateTagsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.confidentialledger.kotlin.inputs

import com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Tags for Managed CCF Certificates
 * @property tags Additional tags for Managed CCF Certificates
 */
public data class CertificateTagsArgs(
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs> {
    override fun toJava(): com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs =
        com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs.builder()
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [CertificateTagsArgs].
 */
@PulumiTagMarker
public class CertificateTagsArgsBuilder internal constructor() {
    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Additional tags for Managed CCF Certificates
     */
    @JvmName("lrvuupdoaaeglweh")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Additional tags for Managed CCF Certificates
     */
    @JvmName("pqpbdvuavdjfeexm")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Additional tags for Managed CCF Certificates
     */
    @JvmName("gidrcgqtxtuicewg")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): CertificateTagsArgs = CertificateTagsArgs(
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/confidentialledger/kotlin/inputs/CertificateTagsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.confidentialledger.kotlin.inputs

import com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Tags for Managed CCF Certificates
 * @property tags Additional tags for Managed CCF Certificates
 */
public data class CertificateTagsArgs(
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs> {
    override fun toJava(): com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs =
        com.pulumi.azurenative.confidentialledger.inputs.CertificateTagsArgs.builder()
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [CertificateTagsArgs].
 */
@PulumiTagMarker
public class CertificateTagsArgsBuilder internal constructor() {
    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Additional tags for Managed CCF Certificates
     */
    @JvmName("wgywjvlyhxpimuib")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Additional tags for Managed CCF Certificates
     */
    @JvmName("lrekxmjnjyokavju")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Additional tags for Managed CCF Certificates
     */
    @JvmName("bahwlseurmadkwaa")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): CertificateTagsArgs = CertificateTagsArgs(
        tags = tags,
    )
}
